criterium.agent.wrapper

Direct access wrappers for Agent class methods.

This namespace imports criterium.agent.Agent and provides Clojure functions that compile to direct field access and static method calls, avoiding reflection.

This namespace will fail to load if the Agent class is not available.

Direct access wrappers for Agent class methods.

This namespace imports criterium.agent.Agent and provides Clojure
functions that compile to direct field access and static method calls,
avoiding reflection.

This namespace will fail to load if the Agent class is not available.
raw docstring

allocation-finish-markerclj

(allocation-finish-marker)

Call Agent.allocation_finish_marker directly.

Call Agent.allocation_finish_marker directly.
sourceraw docstring

allocation-start-markerclj

(allocation-start-marker)

Call Agent.allocation_start_marker directly.

Call Agent.allocation_start_marker directly.
sourceraw docstring

method-tracing-finish-markerclj

(method-tracing-finish-marker)

Call Agent.method_tracing_finish_marker directly. Generates a method entry event that triggers completion of tracing.

Call Agent.method_tracing_finish_marker directly.
Generates a method entry event that triggers completion of tracing.
sourceraw docstring

method-tracing-start-markerclj

(method-tracing-start-marker)

Call Agent.method_tracing_start_marker directly. Generates a method entry event that triggers transition to active state.

Call Agent.method_tracing_start_marker directly.
Generates a method entry event that triggers transition to active state.
sourceraw docstring

read-stateclj

(read-state)

Read Agent.state field directly.

Read Agent.state field directly.
sourceraw docstring

send-commandclj

(send-command cmd)

Call Agent.command directly.

Call Agent.command directly.
sourceraw docstring

set-handlerclj

(set-handler handler-fn)

Call Agent.set_handler directly.

Call Agent.set_handler directly.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries