criterium.bench.config


*default-viewer*clj

Dynamic var for the default viewer to use when no explicit :viewer option is provided. Initial value is :print.

This can be bound dynamically or altered via set-default-viewer!.

Precedence (highest to lowest):

  1. Explicit :viewer option on bench call
  2. :viewer from bench-plan (if provided)
  3. This dynamic default viewer
  4. Hard-coded fallback :print (if this var is nil)
Dynamic var for the default viewer to use when no explicit :viewer option
is provided. Initial value is :print.

This can be bound dynamically or altered via set-default-viewer!.

Precedence (highest to lowest):
1. Explicit :viewer option on bench call
2. :viewer from bench-plan (if provided)
3. This dynamic default viewer
4. Hard-coded fallback :print (if this var is nil)
sourceraw docstring

config-mapclj

(config-map options-map)

Convert option arguments into a criterium configuration map. The config map specifies how criterium will execute.

Convert option arguments into a criterium configuration map.
The config map specifies how criterium will execute.
sourceraw docstring

metric-ids->collector-configclj

(metric-ids->collector-config metric-ids)
source

set-default-viewer!clj

(set-default-viewer! viewer)

Set the default viewer for all bench calls that don't specify an explicit :viewer option.

viewer - Keyword identifying the viewer, e.g. :print, :pprint, :portal, :kindly

Example: (set-default-viewer! :kindly) (bench (+ 1 1)) ; Now uses :kindly viewer by default

Set the default viewer for all bench calls that don't specify an explicit
:viewer option.

viewer - Keyword identifying the viewer,
         e.g. :print, :pprint, :portal, :kindly

Example:
  (set-default-viewer! :kindly)
  (bench (+ 1 1))  ; Now uses :kindly viewer by default
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries