criterium.collect-plan

Collection plan to control the collection of metrics from a measured.

Collection plan to control the collection of metrics from a measured.
raw docstring

collectclj

(collect collect-plan collector measured)

Collect metrics from the measured according to the collect-plan. Return a results-map.

Collect metrics from the measured according to the collect-plan.
Return a results-map.
sourceraw docstring

identity-transformsclj

source

required-stagesclj

(required-stages collect-plan-id)

Metrics collection stages required for the given collection-scheme

Metrics collection stages required for the given collection-scheme
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries