criterium.collector.impl


maybe-var-get-configclj

(maybe-var-get-config config)
source

maybe-var-get-stageclj

(maybe-var-get-stage x)
source

maybe-var-get-stagesclj

(maybe-var-get-stages x)
source

metric-idsclj

(metric-ids {:keys [stages terminator] :as _pipline-config})

Return a sequence of all metrics produced by a pipeline with the given pipeline config.

Each stage can specify a :metric-id that differs from its :id. When present, :metric-id is used; otherwise :id is used.

Return a sequence of all metrics produced by a pipeline with the
given pipeline config.

Each stage can specify a :metric-id that differs from its :id.
When present, :metric-id is used; otherwise :id is used.
sourceraw docstring

pipeline*clj

(pipeline* collector-config)

Build a pipeline by specifying pipeline function keywords.

Returns an updated state, adding :pipeline and :metrics keys.

Build a pipeline by specifying pipeline function keywords.

Returns an updated state, adding :pipeline and :metrics keys.
sourceraw docstring

pipeline-sample-fnclj

(pipeline-sample-fn collector-config)

Build a pipeline sample function by specifying pipeline function keywords.

Returns a function to collect a sample.

Build a pipeline sample function by specifying pipeline function keywords.

Returns a function to collect a sample.
sourceraw docstring

pipeline-sample-fn*clj

(pipeline-sample-fn* {:keys [stages terminator] :as collector-config})

Build a pipeline sample function by specifying pipeline function keywords.

Returns a function to collect a sample.

Build a pipeline sample function by specifying pipeline function keywords.

Returns a function to collect a sample.
sourceraw docstring

pipeline-xform-fnclj

(pipeline-xform-fn {:keys [stages terminator] :as _collector-config})

Build a pipeline xform by specifying pipeline function keywords.

Returns an xform function.

Build a pipeline xform by specifying pipeline function keywords.

Returns an xform function.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries