criterium.jvm.impl


class-loader-countsclj

(class-loader-counts)
source

class-loader-counts-changeclj

(class-loader-counts-change first-sample last-sample)
source

compilationclj

(compilation sample)
source

compilation-changeclj

(compilation-change first-sample last-sample)
source

compilation-sampleclj

(compilation-sample)
source

current-thread-idclj

(current-thread-id)
source

finalizationclj

(finalization finalization-sample)
source

finalization-changeclj

(finalization-change first-sample last-sample)
source

finalization-sampleclj

(finalization-sample)
source

garbage-collectorclj

(garbage-collector sample)
source

garbage-collector-bean-samplescljmacro

(garbage-collector-bean-samples)
source

garbage-collector-beansclj

source

garbage-collector-changeclj

(garbage-collector-change first-sample last-sample)
source

garbage-collector-keywordsclj

source

garbage-collector-namesclj

(garbage-collector-names)
source

garbage-collector-sampleclj

(garbage-collector-sample)
source

jit-nameclj

(jit-name)

Returns the name of the JIT compiler.

Returns the name of the JIT compiler.
sourceraw docstring

memoryclj

(memory memory-sample)

Return a map of the memory usage for the JVM instance.

Return a map of the memory usage for the JVM instance.
sourceraw docstring

memory-changeclj

(memory-change first-memory-sample last-memory-sample)

Return a map of the change in memory usage between first and last samples.

Return a map of the change in memory usage between first and last samples.
sourceraw docstring

memory-pool-beansclj

source

memory-pool-beans-samplescljmacro

(memory-pool-beans-samples)
source

memory-pool-keywordsclj

source

memory-pool-namesclj

(memory-pool-names)
source

memory-poolsclj

(memory-pools sample)
source

memory-pools-changeclj

(memory-pools-change first-sample last-sample)
source

memory-pools-sampleclj

(memory-pools-sample)
source

memory-sampleclj

(memory-sample)
source

os-detailsclj

(os-details)

Return the operating system details as a hash.

Return the operating system details as a hash.
sourceraw docstring

runtime-detailsclj

(runtime-details)
source

set-memory-verbose!clj

(set-memory-verbose! flag)

Set whether the memory collection system emits verbose output.

Set whether the memory collection system emits verbose output.
sourceraw docstring

set-thread-contention-monitoring-enabledclj

(set-thread-contention-monitoring-enabled flag)
source

set-thread-cpu-time-enabledclj

(set-thread-cpu-time-enabled flag)
source

set-verbose-classloadingclj

(set-verbose-classloading flag)

Set whether the classloader is verbose or not.

Set whether the classloader is verbose or not.
sourceraw docstring

system-propertiesclj

(system-properties)
source

threadclj

(thread sample)
source

thread-allocated-bytesclj

(thread-allocated-bytes id)
source

thread-changeclj

(thread-change first-sample last-sample)
source

thread-cpu-timeclj

(thread-cpu-time id)
source

thread-idsclj

(thread-ids)
source

thread-info-mapclj

(thread-info-map thread-info)
source

thread-sampleclj

(thread-sample id)
source

thread-user-timeclj

(thread-user-time id)
source

threads-summary-sampleclj

(threads-summary-sample)
source

cljdoc builds & hosts documentation for Clojure/Script libraries