criterium.platform

Platform characterisation

Platform characterisation
raw docstring

-mainclj

(-main)

Output a table of the platform min and mean point estimates. Compatible with deps.edn :main.

Output a table of the platform min and mean point estimates.
Compatible with deps.edn :main.
sourceraw docstring

constant-doubleclj

(constant-double)
(constant-double options)
source

constant-longclj

(constant-long)
(constant-long options)
source

constant-nilclj

(constant-nil)
(constant-nil options)
source

constant-objectclj

(constant-object)
(constant-object options)
source

exec-mainclj

(exec-main _opts)

Output a table of the platform min and mean point estimates. Compatible with deps.edn :exec-fn.

Output a table of the platform min and mean point estimates.
Compatible with deps.edn :exec-fn.
sourceraw docstring

jit-threasholdsclj

(jit-threasholds)
(jit-threasholds _options)

Estimate how many iterations are required for JIT compilation. This is not very accurate, as JIT runs in the background, and there are several compilation targets.

The highest value returned should be less than TARGET-WARMUP-SAMPLES for our collection plans to be realistic.

Estimate how many iterations are required for JIT compilation.
This is not very accurate, as JIT runs in the background, and there
are several compilation targets.

The highest value returned should be less than TARGET-WARMUP-SAMPLES for
our collection plans to be realistic.
sourceraw docstring

nanotime-granularityclj

(nanotime-granularity)
(nanotime-granularity options)
source

nanotime-granularity-measuredclj

source

nanotime-latencyclj

(nanotime-latency)
(nanotime-latency options)
source

platform-point-estimatesclj

(platform-point-estimates)
(platform-point-estimates options)

Return estimates for times that describe the accuracy of timing.

The latency and granularity are min estimate, and the the rest are mean estimates.

Return estimates for times that describe the accuracy of timing.

The latency and granularity are min estimate, and the the rest are
mean estimates.
sourceraw docstring

platform-statsclj

(platform-stats)
(platform-stats options)

Return a sequence of estimates for times that describe accuracy of timing.

Each estimate has a :name value.

Return a sequence of estimates for times that describe accuracy of timing.

Each estimate has a :name value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries