criterium.random.interface

Public API for the random component.

Provides pseudo-random number generation:

  • WELL RNG 1024a algorithm for high-quality uniform random doubles
  • Ziggurat algorithm for normal (Gaussian) random variates

Primary API (mutable RNGs for performance):

  • make-well-rng-1024a - Create a uniform RNG
  • next-double! - Generate next uniform random double in [0,1)
  • make-normal-rng - Create a normal/Gaussian RNG
  • next-gaussian! - Generate next standard normal variate

References:

  • WELL RNG: Improved Long-Period Generators Based on Linear Recurrences Modulo 2, F. Panneton, P. L'Ecuyer and M. Matsumoto http://www.iro.umontreal.ca/~panneton/WELLRNG.html
  • Ziggurat: An improved Ziggurat method to generate normal random samples, Doornik, 2005
Public API for the random component.

Provides pseudo-random number generation:
- WELL RNG 1024a algorithm for high-quality uniform random doubles
- Ziggurat algorithm for normal (Gaussian) random variates

Primary API (mutable RNGs for performance):
- `make-well-rng-1024a` - Create a uniform RNG
- `next-double!` - Generate next uniform random double in [0,1)
- `make-normal-rng` - Create a normal/Gaussian RNG
- `next-gaussian!` - Generate next standard normal variate

References:
- WELL RNG: Improved Long-Period Generators Based on Linear Recurrences
  Modulo 2, F. Panneton, P. L'Ecuyer and M. Matsumoto
  http://www.iro.umontreal.ca/~panneton/WELLRNG.html
- Ziggurat: An improved Ziggurat method to generate normal random samples,
  Doornik, 2005
raw docstring

criterium.random.ziggurat

Ziggurat algorithm for generating normal random variates.

See: An improved Ziggurat method to generate normal random samples, Doornik, 2005

Ziggurat algorithm for generating normal random variates.

See: An improved Ziggurat method to generate normal random samples,
Doornik, 2005
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries