criterium.random.well


add-mod-32cljmacro

(add-mod-32 a b)
source

bit-shift-right-nscljmacro

(bit-shift-right-ns a b)

A bit shift that doesn't do sign extension.

A bit shift that doesn't do sign extension.
sourceraw docstring

int-maxclj

(int-max)
source

limit-bitscljmacro

(limit-bits x)
source

make-well-rng-1024aclj

(make-well-rng-1024a)
(make-well-rng-1024a seed)

Create a WellRng1024a instance. Returns a mutable RNG that generates doubles in [0,1) via next-double!.

Arities:

  • () - Uses non-deterministic seed from rand-int
  • (seed) - Uses java.util.Random with given seed for deterministic output

See: Improved Long-Period Generators Based on Linear Recurrences Modulo 2 F. Panneton, P. L'Ecuyer and M. Matsumoto http://www.iro.umontreal.ca/~panneton/WELLRNG.html

Create a WellRng1024a instance.
Returns a mutable RNG that generates doubles in [0,1) via next-double!.

Arities:
- () - Uses non-deterministic seed from rand-int
- (seed) - Uses java.util.Random with given seed for deterministic output

See: Improved Long-Period Generators Based on Linear Recurrences Modulo 2
F. Panneton, P. L'Ecuyer and M. Matsumoto
http://www.iro.umontreal.ca/~panneton/WELLRNG.html
sourceraw docstring

mat0-negcljmacro

(mat0-neg t v)
source

mat0-poscljmacro

(mat0-pos t v)
source

next-double!clj

(next-double! rng)

Generate the next random double in [0,1), mutating the RNG state. Returns a double.

Generate the next random double in [0,1), mutating the RNG state.
Returns a double.
sourceraw docstring

unsigncljmacro

(unsign x)

Convert a result based on a signed integer, and convert it to what it would have been for an unsigned integer.

Convert a result based on a signed integer, and convert it to what it would
have been for an unsigned integer.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries