Protocol and utilities for working with performance sampling state.
Provides a standard interface for components that collect and store performance metrics samples during execution.
Protocol and utilities for working with performance sampling state. Provides a standard interface for components that collect and store performance metrics samples during execution.
Protocol for accessing sampling state
Protocol for accessing sampling state
(reset-samples! this)Clear all collected samples
Clear all collected samples
(samples-map this)Get the current samples collected
Get the current samples collected
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |