criterium.stats.kernel

Kernel functions for density estimation.

Provides kernel weight functions and basic kernel density estimators for modal estimation and bandwidth selection.

Kernel functions for density estimation.

Provides kernel weight functions and basic kernel density estimators
for modal estimation and bandwidth selection.
raw docstring

gaussian-weightclj

(gaussian-weight t)

Weight function for gaussian kernel. K(t) = (1/sqrt(2*pi)) * exp(-t^2/2)

Weight function for gaussian kernel.
K(t) = (1/sqrt(2*pi)) * exp(-t^2/2)
sourceraw docstring

kernel-density-estimatorclj

(kernel-density-estimator h K n X x)

Kernel density estimator for x, given n samples X, weights K and width h. Computes f(x) = (1/nh) * sum_i K((x - X_i)/h)

Kernel density estimator for x, given n samples X, weights K and width h.
Computes f(x) = (1/nh) * sum_i K((x - X_i)/h)
sourceraw docstring

(modal-estimation-constant h-k sample-variance)

Kernel function for estimation of multi-modality. h-k is the critical bandwidth, sample-variance is the observed sample variance. Equation 7, Nonparametric assessment of multimodality for univariate data. Salgado-Ugarte IH, Shimizu M

Kernel function for estimation of multi-modality.
h-k is the critical bandwidth, sample-variance is the observed sample variance.
Equation 7, Nonparametric assessment of multimodality for univariate
data. Salgado-Ugarte IH, Shimizu M
sourceraw docstring

smoothed-sampleclj

(smoothed-sample c-k h-k data deviates)

Smoothed estimation function. Generates a lazy sequence of smoothed values from data using kernel smoothing.

Smoothed estimation function.
Generates a lazy sequence of smoothed values from data using kernel smoothing.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries