criterium.stats.t-digest.merging-digest

Implementation of the t-digest algorithm for streaming quantile estimation. Based on the MergingDigest variant from https://github.com/tdunning/t-digest

Implementation of the t-digest algorithm for streaming quantile estimation.
Based on the MergingDigest variant from https://github.com/tdunning/t-digest
raw docstring

add-pointclj

(add-point digest value)
(add-point {:keys [temp-centroids] :as digest} value weight)

Adds a single value with weight to the digest

Adds a single value with weight to the digest
sourceraw docstring

cdfclj

(cdf {:keys [centroids] :as digest} x)

Returns cumulative probability at x. Returns NaN if digest is empty.

Returns cumulative probability at x.
Returns NaN if digest is empty.
sourceraw docstring

centroid-meanclj

(centroid-mean centroid)
source

centroid-meansclj

(centroid-means digest)
source

centroid-weightclj

(centroid-weight centroid)
source

compressclj

(compress digest)

Merges any buffered points into the digest.

Merges any buffered points into the digest.
sourceraw docstring

compressed?clj

(compressed? {:keys [temp-centroids] :as _digest})
source

filter-outliersclj

(filter-outliers digest outliers)
source

histogramclj

(histogram digest iqr)

Returns a histogram of the digest using centroid centers as bin locations.

  • counts: Number of samples in each bin
  • centers: Bin center locations
  • widths: Width of each bin
  • density: Normalized density (count/width) for each bin
  • n: Total sample count
  • num-bins: Number of bins
  • min: Minimum value
  • max: Maximum value
Returns a histogram of the digest using centroid centers as bin locations.
- counts: Number of samples in each bin
- centers: Bin center locations
- widths: Width of each bin
- density: Normalized density (count/width) for each bin
- n: Total sample count
- num-bins: Number of bins
- min: Minimum value
- max: Maximum value
sourceraw docstring

interpolatecljmacro

(interpolate v0 v1 x0 x1 x)
source

interpolate-centroidsclj

(interpolate-centroids left right x)
source

maximumclj

(maximum digest)
source

meanclj

(mean {:keys [centroids] :as digest})
source

minimumclj

(minimum digest)
source

new-digestclj

(new-digest)
(new-digest compression)
(new-digest compression buffer-size)

Creates a new t-digest with given compression factor.

Creates a new t-digest with given compression factor.
sourceraw docstring

quantileclj

(quantile {:keys [centroids] :as digest} q)

Returns estimated value at given quantile (0-1). Returns NaN if digest is empty.

Returns estimated value at given quantile (0-1).
Returns NaN if digest is empty.
sourceraw docstring

sample-countclj

(sample-count digest)
source

transformclj

(transform {:keys [buffer-size compression centroids] :as digest} f)
source

varianceclj

(variance digest)
(variance {:keys [centroids] :as digest} mean)

Returns the sample variance of the distribution represented by the t-digest. Uses n-1 in the denominator (Bessel's correction).

Returns the sample variance of the distribution represented by the t-digest.
Uses n-1 in the denominator (Bessel's correction).
sourceraw docstring

vfirstclj

(vfirst v)
source

vpeekclj

(vpeek v)
source

vsecondclj

(vsecond v)
source

cljdoc builds & hosts documentation for Clojure/Script libraries