Blackhole wrapper for preventing dead code elimination. Delegates to criterium.blackhole.
Blackhole wrapper for preventing dead code elimination. Delegates to criterium.blackhole.
Bootstrap statistics for criterium.
Core bootstrap algorithms are provided by criterium.stats.bootstrap. This namespace provides criterium-specific integration with metrics and collect plans.
Bootstrap statistics for criterium. Core bootstrap algorithms are provided by criterium.stats.bootstrap. This namespace provides criterium-specific integration with metrics and collect plans.
Metric formatters
Metric formatters
Control flow macros.
This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Control flow macros. This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Criterium domain helpers and backward-compatible re-exports from utils.
Criterium domain helpers and backward-compatible re-exports from utils.
Assertion macros inspired by truss.
This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Assertion macros inspired by truss. This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Re-exports t-digest functionality from stats component for backward compatibility.
Re-exports t-digest functionality from stats component for backward compatibility.
Re-exports merging-digest functions from stats component for backward compatibility.
Re-exports merging-digest functions from stats component for backward compatibility.
Re-exports scale functions from stats component for backward compatibility.
Re-exports scale functions from stats component for backward compatibility.
Generic utility functions.
Generic utility functions.
Public API for the utils component.
Provides generic utilities including:
Public API for the utils component. Provides generic utilities including: - Assertion macros (have, have?) - Control flow macros (cond*) - Math utilities (sqr, sqrd, cubed, trunc) - Collection utilities (update-vals, filter-map, deep-merge) - Tree walking (walk, postwalk) - Debugging (spy, report)
Assertion macros inspired by truss.
Assertion macros inspired by truss.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |