criterium.util.helpers

Criterium domain helpers and backward-compatible re-exports from utils.

Criterium domain helpers and backward-compatible re-exports from utils.
raw docstring

->autocorrelation-classification-mapclj

(->autocorrelation-classification-map x)

Identity wrapper for autocorrelation-classification-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for autocorrelation-classification-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->autocorrelation-mapclj

(->autocorrelation-map x)

Identity wrapper for autocorrelation-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for autocorrelation-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->collected-metrics-mapclj

(->collected-metrics-map x)

Identity wrapper for collected-metrics-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for collected-metrics-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->distribution-fit-mapclj

(->distribution-fit-map x)

Identity wrapper for distribution-fit-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for distribution-fit-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->effective-sample-size-mapclj

(->effective-sample-size-map x)

Identity wrapper for effective-sample-size-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for effective-sample-size-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->event-stats-mapclj

(->event-stats-map x)

Identity wrapper for event-stats-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for event-stats-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->histogram-mapclj

(->histogram-map x)

Identity wrapper for histogram-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for histogram-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->kde-mapclj

(->kde-map x)

Identity wrapper for kde-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for kde-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->modes-mapclj

(->modes-map x)

Identity wrapper for modes-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for modes-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->outlier-significance-mapclj

(->outlier-significance-map x)

Identity wrapper for outlier-significance-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for outlier-significance-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->outliers-mapclj

(->outliers-map x)

Identity wrapper for outliers-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for outliers-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->quantiles-mapclj

(->quantiles-map x)

Identity wrapper for quantiles-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for quantiles-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->stats-mapclj

(->stats-map x)

Identity wrapper for stats-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for stats-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

->tail-analysis-mapclj

(->tail-analysis-map x)

Identity wrapper for tail-analysis-map construction. Validation handled by malli instrumentation during development.

Identity wrapper for tail-analysis-map construction.
Validation handled by malli instrumentation during development.
sourceraw docstring

add-transform-pathsclj

(add-transform-paths v sample-> ->sample)
source

assoc-tagclj

source

autocorrelationclj

(autocorrelation autocorrelation-map)
source

autocorrelation-classification-dataclj

(autocorrelation-classification-data class-map)

Extract classification data from an autocorrelation-classification-map.

Extract classification data from an autocorrelation-classification-map.
sourceraw docstring

bootstrapclj

(bootstrap bootstrap-stats-map)
source

bootstrap-box-plot-statsclj

(bootstrap-box-plot-stats data-map metric-id)

Extract all stats needed for box plot from bootstrap data.

Returns a map with :median, :p10, :p90, and optionally :ci-lower, :ci-upper. Returns nil if required quantiles (0.1, 0.5, 0.9) are not available.

Extract all stats needed for box plot from bootstrap data.

Returns a map with :median, :p10, :p90, and optionally :ci-lower, :ci-upper.
Returns nil if required quantiles (0.1, 0.5, 0.9) are not available.
sourceraw docstring

bootstrap-quantile-ciclj

(bootstrap-quantile-ci data-map metric-id quantile)

Extract confidence interval bounds for a bootstrap quantile.

Returns {:ci-lower val :ci-upper val} map with transforms applied, or nil if CI bounds are not available or bootstrap stats are missing.

Extract confidence interval bounds for a bootstrap quantile.

Returns {:ci-lower val :ci-upper val} map with transforms applied,
or nil if CI bounds are not available or bootstrap stats are missing.
sourceraw docstring

bootstrap-quantile-valueclj

(bootstrap-quantile-value data-map metric-id quantile)

Extract a transformed bootstrap quantile value from a benchmark data map.

Takes a data map, metric-id (e.g. :elapsed-time), and quantile (e.g. 0.5). Returns the point estimate for that quantile with transforms applied, or nil if bootstrap stats are not available.

Bootstrap stats structure: [:bootstrap-stats :bootstrap metric-id :quantiles q] where each quantile has :point-estimate and :estimate-quantiles.

Extract a transformed bootstrap quantile value from a benchmark data map.

Takes a data map, metric-id (e.g. :elapsed-time), and quantile (e.g. 0.5).
Returns the point estimate for that quantile with transforms applied,
or nil if bootstrap stats are not available.

Bootstrap stats structure:
   [:bootstrap-stats :bootstrap metric-id :quantiles q]
where each quantile has :point-estimate and :estimate-quantiles.
sourceraw docstring

cubedclj

source

dataclj

(data data-entry-map)
source

data-entry-mapclj

(data-entry-map data type transform source-id)
source

deep-mergeclj

source

effective-sample-size-dataclj

(effective-sample-size-data ess-map)

Extract effective sample size data from an effective-sample-size-map.

Extract effective sample size data from an effective-sample-size-map.
sourceraw docstring

event-statsclj

(event-stats event-stats-map)
source

filter-mapclj

source

get-generic-data-entryclj

(get-generic-data-entry result-map id)

Look up a generic data entry by id from a result map. Returns the entry or nil if not found. Type validation is handled by malli instrumentation during development.

Look up a generic data entry by id from a result map.
Returns the entry or nil if not found. Type validation is
handled by malli instrumentation during development.
sourceraw docstring

get-quantiles-entryclj

(get-quantiles-entry result-map id)

Look up a quantiles entry by id from a result map. Returns the entry or nil if not found. Type validation is handled by malli instrumentation during development.

Look up a quantiles entry by id from a result map.
Returns the entry or nil if not found. Type validation is
handled by malli instrumentation during development.
sourceraw docstring

get-transformsclj

(get-transforms result-map path)
source

lookup-dataclj

(lookup-data data-map id)
source

maybe-var-getclj

(maybe-var-get x options)

Resolve and deref a Named, or return the argument.

Resolve and deref a Named, or return the argument.
sourceraw docstring

maybe-ver-get-namedclj

(maybe-ver-get-named k {:keys [default-ns]})

Resolve and deref a Named, or return the argument.

Resolve and deref a Named, or return the argument.
sourceraw docstring

metric->digestclj

(metric->digest digest-samples)
source

metric->valuesclj

(metric->values metrics-samples)
source

outlier-significanceclj

(outlier-significance outlier-significance-map)
source

outliersclj

(outliers outliers-map)
source

postwalkclj

source

provide-update-valscljmacro

(provide-update-vals)
source

quantilesclj

(quantiles quantiles-map)
source

reduce-double-vectorclj

source

reportclj

source

samples-single-valueclj

(samples-single-value data-map metric-id)

Extract a metric value from raw samples when only a single sample exists. For use with :one-shot benchmarks that produce a single data point without statistical analysis.

Returns the transformed metric value, or nil if samples unavailable, multi-sample, or the metric doesn't exist in the samples.

Extract a metric value from raw samples when only a single sample exists.
For use with :one-shot benchmarks that produce a single data point without
statistical analysis.

Returns the transformed metric value, or nil if samples unavailable,
multi-sample, or the metric doesn't exist in the samples.
sourceraw docstring

spyclj

source

sqrcljmacro

(sqr x)

Square of argument

Square of argument
sourceraw docstring

sqrdclj

source

statsclj

(stats stats-map)
source

stats-valueclj

(stats-value data-map stats-id metric-id value-key)

Extract a transformed stats value from a benchmark data map.

Takes a data map (from bench/last-bench :data), a stats-id (e.g. :stats or :log-stats), a metric-id (e.g. :elapsed-time), and a value-key (e.g. :mean, :std-dev).

Returns the value with all transforms applied, or nil if the stats-id entry is not present in the data map.

Extract a transformed stats value from a benchmark data map.

Takes a data map (from bench/last-bench :data), a stats-id
(e.g. :stats or :log-stats), a metric-id (e.g. :elapsed-time),
and a value-key (e.g. :mean, :std-dev).

Returns the value with all transforms applied, or nil if the
stats-id entry is not present in the data map.
sourceraw docstring

sumclj

(sum)
(sum a b)
source

transform->sampleclj

(transform->sample value transforms)
source

transform-sample->clj

(transform-sample-> value transforms)
source

transform-vals->clj

(transform-vals-> m transforms)
source

truncclj

source

update-valsclj

source

update-vals-implclj

source

valid-thread-priorityclj

(valid-thread-priority p)
source

walkclj

source

with-thread-prioritycljmacro

(with-thread-priority p & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries