Assertion macros inspired by truss.
This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Assertion macros inspired by truss. This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
(have x)(have f x)(have f x data)Assertion macro inspired by truss.
Assertion macro inspired by truss.
(have? x & args)Assertion macro inspired by truss.
Assertion macro inspired by truss.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |