criterium.util.t-digest.scale

Re-exports scale functions from stats component for backward compatibility.

Re-exports scale functions from stats component for backward compatibility.
raw docstring

boundclj

source

finite?clj

source

kclj

source

k0clj

source

k1clj

source

k1-k-limit-f-lowclj

source

k1-q-limit-f-highclj

source

k1-q-limit-highclj

source

k1-q-limit-lowclj

source

k1-x-limit-highclj

source

k1-x-limit-lowclj

source

k2clj

source

limitclj

source

max-sizeclj

source

normalizerclj

source

qclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries