Autocorrelation view helpers.
Provides functions for formatting autocorrelation data and iterating over metrics for display. Used by print and pprint viewers.
Autocorrelation view helpers. Provides functions for formatting autocorrelation data and iterating over metrics for display. Used by print and pprint viewers.
(collect-classification-metrics {:keys [classification-id autocorrelation-id]}
data-map)Collect classification data for all metrics. Returns seq of [class-data acf-data mc]. Uses :classification-id to get classification analysis results, and looks up the source autocorrelation for lag-1 data.
Collect classification data for all metrics. Returns seq of [class-data acf-data mc]. Uses :classification-id to get classification analysis results, and looks up the source autocorrelation for lag-1 data.
(collect-ess-metrics {:keys [ess-id autocorrelation-id]} data-map)Collect ESS data for all metrics. Returns seq of [ess-data acf-data mc]. Uses :ess-id to get ESS analysis results, and looks up the source autocorrelation for lag-1 data.
Collect ESS data for all metrics. Returns seq of [ess-data acf-data mc]. Uses :ess-id to get ESS analysis results, and looks up the source autocorrelation for lag-1 data.
Patterns that warrant display of pattern label and recommendations. Excludes :clean, :alternating-none, and :alternating-minor.
Patterns that warrant display of pattern label and recommendations. Excludes :clean, :alternating-none, and :alternating-minor.
(format-anomalous-lags anomalous-lags lag-severities)Format anomalous lags for display. Takes a vector of lag numbers and a map of lag -> severity. Returns a string like '1 (minor), 12 (moderate)' or nil if empty.
Format anomalous lags for display. Takes a vector of lag numbers and a map of lag -> severity. Returns a string like '1 (minor), 12 (moderate)' or nil if empty.
(format-detected-period detected-period acf-map lag-severities)Format detected period with ACF value and severity. Returns a string like '60 samples (r=0.35, moderate)' or nil if period is nil.
Format detected period with ACF value and severity. Returns a string like '60 samples (r=0.35, moderate)' or nil if period is nil.
(format-severity severity)Format a severity keyword for display.
Format a severity keyword for display.
Human-readable labels for pattern keywords.
Human-readable labels for pattern keywords.
Recommendations for each displayable pattern.
Recommendations for each displayable pattern.
Human-readable labels for severity keywords.
Human-readable labels for severity keywords.
(with-autocorrelation-metrics {:keys [autocorrelation-id]} data-map f)Helper for autocorrelation views. Calls f for each metric with acf-data. f receives acf-data and metric-config.
Helper for autocorrelation views. Calls f for each metric with acf-data. f receives acf-data and metric-config.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |