criterium.viewer.kindly

A viewer that outputs Kindly-annotated data structures for Clay notebooks.

Uses an accumulator pattern where view functions append Kindly-annotated values to an atom. The flush-viewer multimethod returns a kind/fragment combining all accumulated values.

No runtime dependency on scicloj/kindly - produces plain maps with appropriate :kindly/kind metadata.

A viewer that outputs Kindly-annotated data structures for Clay notebooks.

Uses an accumulator pattern where view functions append Kindly-annotated
values to an atom. The `flush-viewer` multimethod returns a `kind/fragment`
combining all accumulated values.

No runtime dependency on scicloj/kindly - produces plain maps with
appropriate `:kindly/kind` metadata.
raw docstring

accumulatedclj

Accumulator for Kindly-annotated values.

Accumulator for Kindly-annotated values.
sourceraw docstring

flushclj

Return accumulated values as a kind/fragment and clear the accumulator. Also stores the fragment in last-fragment for retrieval after bench completes.

Return accumulated values as a kind/fragment and clear the accumulator.
Also stores the fragment in `last-fragment` for retrieval after bench
completes.
sourceraw docstring

kindly-addclj

Add a value to the accumulator.

Add a value to the accumulator.
sourceraw docstring

kindly-headingclj

Add a markdown heading to the accumulator.

Add a markdown heading to the accumulator.
sourceraw docstring

kindly-tableclj

Add a table to the accumulator. Optionally accepts :column-names in opts for explicit column ordering.

Add a table to the accumulator.
Optionally accepts :column-names in opts for explicit column ordering.
sourceraw docstring

kindly-vegaclj

Add a full Vega chart to the accumulator.

Add a full Vega chart to the accumulator.
sourceraw docstring

kindly-vega-liteclj

Add a Vega-Lite chart to the accumulator.

Add a Vega-Lite chart to the accumulator.
sourceraw docstring

last-fragmentclj

Last flushed Kindly fragment for retrieval after bench completes.

Last flushed Kindly fragment for retrieval after bench completes.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries