Kindly viewer core functions for basic metrics display.
Provides Kindly-annotated output for:
Uses an accumulator pattern where view functions append Kindly-annotated
values to an atom. The flush-viewer multimethod returns a kind/fragment
combining all accumulated values.
No runtime dependency on scicloj/kindly - produces plain maps with
appropriate :kindly/kind metadata.
Kindly viewer core functions for basic metrics display. Provides Kindly-annotated output for: - metrics, stats, extremes - bootstrap statistics - samples, histograms, KDE - outlier counts and significance - event stats (class loader, JIT, GC) - quantiles, sample percentiles, sample diffs - collect plan, OS, and runtime info Uses an accumulator pattern where view functions append Kindly-annotated values to an atom. The `flush-viewer` multimethod returns a `kind/fragment` combining all accumulated values. No runtime dependency on scicloj/kindly - produces plain maps with appropriate `:kindly/kind` metadata.
Accumulator for Kindly-annotated values.
Accumulator for Kindly-annotated values.
Height for Kindly vega-lite charts, sized for notebook display.
Height for Kindly vega-lite charts, sized for notebook display.
Width for Kindly vega-lite charts, sized for notebook display.
Width for Kindly vega-lite charts, sized for notebook display.
(flush)Return accumulated values as a kind/fragment and clear the accumulator.
Also stores the fragment in last-fragment for retrieval after bench
completes.
Return accumulated values as a kind/fragment and clear the accumulator. Also stores the fragment in `last-fragment` for retrieval after bench completes.
(kindly-add value)Add a value to the accumulator.
Add a value to the accumulator.
(kindly-heading s)Add a markdown heading to the accumulator.
Add a markdown heading to the accumulator.
(kindly-table data)(kindly-table data {:keys [column-names]})Add a table to the accumulator. Optionally accepts :column-names in opts for explicit column ordering.
Add a table to the accumulator. Optionally accepts :column-names in opts for explicit column ordering.
(kindly-vega spec)Add a full Vega chart to the accumulator.
Add a full Vega chart to the accumulator.
(kindly-vega-lite spec)Add a Vega-Lite chart to the accumulator.
Add a Vega-Lite chart to the accumulator.
Last flushed Kindly fragment for retrieval after bench completes.
Last flushed Kindly fragment for retrieval after bench completes.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |