A viewer that outputs to portal using tap>.
Core functionality (tap infrastructure, metrics, stats, extremes, bootstrap, samples, outliers, events, KDE) is in criterium.viewer.portal.core.
Domain analysis views (grouped, extract, comparison, regression, apply) are in criterium.viewer.portal.domain.
Allocation profiling views (summary, hotspots, by-type, treemap) are in criterium.viewer.portal.allocation.
Distribution fit views (models, parameter CIs, PDF, CDF, Q-Q charts) are in criterium.viewer.portal.distribution.
Tail analysis views (summary, ratios, high quantiles, charts) are in criterium.viewer.portal.tail.
Shape statistics views (skewness, kurtosis, CV) are in criterium.viewer.portal.shape.
Modal analysis views (multimodal warnings) are in criterium.viewer.portal.modal.
Autocorrelation analysis views (ACF plots, classification, ESS) are in criterium.viewer.portal.autocorrelation.
A viewer that outputs to portal using tap>. Core functionality (tap infrastructure, metrics, stats, extremes, bootstrap, samples, outliers, events, KDE) is in criterium.viewer.portal.core. Domain analysis views (grouped, extract, comparison, regression, apply) are in criterium.viewer.portal.domain. Allocation profiling views (summary, hotspots, by-type, treemap) are in criterium.viewer.portal.allocation. Distribution fit views (models, parameter CIs, PDF, CDF, Q-Q charts) are in criterium.viewer.portal.distribution. Tail analysis views (summary, ratios, high quantiles, charts) are in criterium.viewer.portal.tail. Shape statistics views (skewness, kurtosis, CV) are in criterium.viewer.portal.shape. Modal analysis views (multimodal warnings) are in criterium.viewer.portal.modal. Autocorrelation analysis views (ACF plots, classification, ESS) are in criterium.viewer.portal.autocorrelation.
Flush tapped output. Delegates to criterium.viewer.portal.core.
Flush tapped output. Delegates to criterium.viewer.portal.core.
Send bold heading to tap>. Delegates to criterium.viewer.portal.core.
Send bold heading to tap>. Delegates to criterium.viewer.portal.core.
Send hiccup-formatted heading to tap>. Delegates to criterium.viewer.portal.core.
Send hiccup-formatted heading to tap>. Delegates to criterium.viewer.portal.core.
Send table data to tap>. Delegates to criterium.viewer.portal.core.
Send table data to tap>. Delegates to criterium.viewer.portal.core.
Send Vega spec to tap>. Delegates to criterium.viewer.portal.core.
Send Vega spec to tap>. Delegates to criterium.viewer.portal.core.
Send Vega-Lite spec to tap>. Delegates to criterium.viewer.portal.core.
Send Vega-Lite spec to tap>. Delegates to criterium.viewer.portal.core.
Tap target function. Delegates to criterium.viewer.portal.core.
Tap target function. Delegates to criterium.viewer.portal.core.
Atom storing tapped values and portal-submit function. Delegates to criterium.viewer.portal.core.
Atom storing tapped values and portal-submit function. Delegates to criterium.viewer.portal.core.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |