criterium.viewer.portal.autocorrelation

Portal viewer for autocorrelation analysis results.

Provides view/* multimethod implementations for displaying autocorrelation diagnostics in Portal, including ACF plots, classification tables, and effective sample size statistics.

Portal viewer for autocorrelation analysis results.

Provides view/* multimethod implementations for displaying autocorrelation
diagnostics in Portal, including ACF plots, classification tables, and
effective sample size statistics.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries