Print viewer functions for allocation profiling display.
Provides text output for:
Print viewer functions for allocation profiling display. Provides text output for: - allocation summary (totals, counts, freed ratio) - allocation hotspots (call sites with highest allocations) - allocations by type (aggregated by object type) - allocation treemap (ASCII tree visualization)
(print-allocation-by-type by-type)Print allocations grouped by object type.
Sorted by bytes descending. Shows count, bytes, freed stats, and type name.
Print allocations grouped by object type. Sorted by bytes descending. Shows count, bytes, freed stats, and type name.
(print-allocation-hotspots hotspots)Print allocation hotspots table.
Each row shows count, bytes, freed stats, object type, and call site. Object types longer than 30 chars are truncated from the start.
Print allocation hotspots table. Each row shows count, bytes, freed stats, object type, and call site. Object types longer than 30 chars are truncated from the start.
(print-allocation-summary {:keys [total-allocated total-freed num-allocations
num-freed freed-ratio]})Print allocation summary statistics.
Displays total allocated/freed bytes, retained memory, allocation/freed counts, and freed ratio percentage.
Print allocation summary statistics. Displays total allocated/freed bytes, retained memory, allocation/freed counts, and freed ratio percentage.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |