criterium.viewer.print.autocorrelation

Print viewer for autocorrelation analysis.

Provides views for lag analysis, effective sample size, CI inflation factors, pattern classification, and ACF plots.

Print viewer for autocorrelation analysis.

Provides views for lag analysis, effective sample size,
CI inflation factors, pattern classification, and ACF plots.
raw docstring

(print-acf-plot acf-data metric-label opts)

Print ASCII ACF plot for a single metric.

Uses the common render-ascii-acf-plot function with print-viewer formatting.

Print ASCII ACF plot for a single metric.

Uses the common render-ascii-acf-plot function with print-viewer formatting.
sourceraw docstring

(print-acf-plots view data-map)

Print ACF plots for all metrics.

Print ACF plots for all metrics.
sourceraw docstring

(print-autocorrelation
  {:keys [acf lag-1 effective-sample-size ci-inflation-factor ljung-box pattern
          classification detected-period anomalous-lags lag-severities]}
  metric-label)

Print autocorrelation analysis summary for a metric.

Output format: Sample Independence: Lag-1 autocorrelation: 0.12 (minor) Effective sample size: 157 of 200 (78%) CI inflation factor: 1.13× Ljung-Box p-value: 0.08 Assessment: Acceptable

For warning/fail, adds pattern and recommendation lines.

Print autocorrelation analysis summary for a metric.

Output format:
Sample Independence:
                    Lag-1 autocorrelation: 0.12 (minor)
                  Effective sample size: 157 of 200 (78%)
                     CI inflation factor: 1.13×
                      Ljung-Box p-value: 0.08
                         Assessment: Acceptable

For warning/fail, adds pattern and recommendation lines.
sourceraw docstring

(print-autocorrelation-classifications view data-map)

Print autocorrelation classification for all metrics. Only outputs if at least one metric is not classified as :pass.

Print autocorrelation classification for all metrics.
Only outputs if at least one metric is not classified as :pass.
sourceraw docstring

(print-autocorrelations view data-map)

Print autocorrelation analysis for all metrics.

Print autocorrelation analysis for all metrics.
sourceraw docstring

(print-effective-sample-sizes view data-map)

Print effective sample size analysis for all metrics. Only outputs if at least one metric has CI inflation factor other than 1.0.

Print effective sample size analysis for all metrics.
Only outputs if at least one metric has CI inflation factor other than 1.0.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries