(jit-name)Returns the name of the JIT compiler.
Returns the name of the JIT compiler.
(memory memory-sample)Return a map of the memory usage for the JVM instance.
Return a map of the memory usage for the JVM instance.
(memory-change first-memory-sample last-memory-sample)Return a map of the change in memory usage between first and last samples.
Return a map of the change in memory usage between first and last samples.
(os-details)Return the operating system details as a hash.
Return the operating system details as a hash.
(set-memory-verbose! flag)Set whether the memory collection system emits verbose output.
Set whether the memory collection system emits verbose output.
(set-verbose-classloading flag)Set whether the classloader is verbose or not.
Set whether the classloader is verbose or not.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |