Platform characterisation
Platform characterisation
(-main)Output a table of the platform min and mean point estimates. Compatible with deps.edn :main.
Output a table of the platform min and mean point estimates. Compatible with deps.edn :main.
(exec-main _opts)Output a table of the platform min and mean point estimates. Compatible with deps.edn :exec-fn.
Output a table of the platform min and mean point estimates. Compatible with deps.edn :exec-fn.
(jit-threasholds)(jit-threasholds _options)Estimate how many iterations are required for JIT compilation. This is not very accurate, as JIT runs in the background, and there are several compilation targets.
The highest value returned should be less than TARGET-WARMUP-SAMPLES for our collection plans to be realistic.
Estimate how many iterations are required for JIT compilation. This is not very accurate, as JIT runs in the background, and there are several compilation targets. The highest value returned should be less than TARGET-WARMUP-SAMPLES for our collection plans to be realistic.
(platform-point-estimates)(platform-point-estimates options)Return estimates for times that describe the accuracy of timing.
The latency and granularity are min estimate, and the the rest are mean estimates.
Return estimates for times that describe the accuracy of timing. The latency and granularity are min estimate, and the the rest are mean estimates.
(platform-stats)(platform-stats options)Return a sequence of estimates for times that describe accuracy of timing.
Each estimate has a :name value.
Return a sequence of estimates for times that describe accuracy of timing. Each estimate has a :name value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |