A viewer that outputs Kindly-annotated data structures for Clay notebooks.
Uses an accumulator pattern where view functions append Kindly-annotated
values to an atom. The flush-viewer multimethod returns a kind/fragment
combining all accumulated values.
No runtime dependency on scicloj/kindly - produces plain maps with
appropriate :kindly/kind metadata.
A viewer that outputs Kindly-annotated data structures for Clay notebooks. Uses an accumulator pattern where view functions append Kindly-annotated values to an atom. The `flush-viewer` multimethod returns a `kind/fragment` combining all accumulated values. No runtime dependency on scicloj/kindly - produces plain maps with appropriate `:kindly/kind` metadata.
Accumulator for Kindly-annotated values.
Accumulator for Kindly-annotated values.
Return accumulated values as a kind/fragment and clear the accumulator.
Also stores the fragment in last-fragment for retrieval after bench
completes.
Return accumulated values as a kind/fragment and clear the accumulator. Also stores the fragment in `last-fragment` for retrieval after bench completes.
Add a markdown heading to the accumulator.
Add a markdown heading to the accumulator.
Add a table to the accumulator. Optionally accepts :column-names in opts for explicit column ordering.
Add a table to the accumulator. Optionally accepts :column-names in opts for explicit column ordering.
Add a full Vega chart to the accumulator.
Add a full Vega chart to the accumulator.
Add a Vega-Lite chart to the accumulator.
Add a Vega-Lite chart to the accumulator.
Last flushed Kindly fragment for retrieval after bench completes.
Last flushed Kindly fragment for retrieval after bench completes.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |